@@ -1,5 +1,8 @@
+import os
+
 __pretty_app_name__ = "e**(j pi) + 1 = 0"
 __app_name__ = "ejpi"
 __version__ = "0.9.6"
-__build__ = 3
+__build__ = 4
+_data_path_ = os.path.join(os.path.expanduser("~"), ".ejpi")
 __app_magic__ = 0xdeadbeef
